@@ -23,12 +23,12 @@
 #include "interfaces/notificationsmodel.h"
 #include "openconfig.h"
 #include "pointerlocker.h"
+#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
+#include "pointerlockerwayland.h"
+#endif
 #include <pluginmodel.h>
 #include <remotecommandsmodel.h>
 #include <remotesinksmodel.h>
-#if WITH_WAYLAND
-#include "pointerlockerwayland.h"
-#endif
 
 QObject *createDBusResponse()
 {
@@ -64,6 +64,7 @@ void KdeConnectDeclarativePlugin::registerTypes(const char *uri)
                                                                0,
                                                                "FindMyPhoneDbusInterface",
                                                                QStringLiteral("You're not supposed to instantiate interfaces"));
+    qmlRegisterUncreatableType<ClipboardDbusInterface>(uri, 1, 0, "ClipboardDbusInterface", QStringLiteral("You're not supposed to instantiate interfaces"));
     qmlRegisterUncreatableType<RemoteKeyboardDbusInterface>(uri,
                                                             1,
                                                             0,
@@ -81,14 +82,13 @@ void KdeConnectDeclarativePlugin::registerTypes(const char *uri)
                                                                 "RemoteSystemVolumeInterface",
                                                                 QStringLiteral("You're not supposed to instantiate interfaces"));
     qmlRegisterUncreatableType<ShareDbusInterface>(uri, 1, 0, "ShareDbusInterface", QStringLiteral("You're not supposed to instantiate interfaces"));
-    qmlRegisterUncreatableType<PhotoDbusInterface>(uri, 1, 0, "PhotoDbusInterface", QStringLiteral("You're not supposed to instantiate interfaces"));
     qmlRegisterUncreatableType<BigscreenDbusInterface>(uri, 1, 0, "BigscreenDbusInterface", QStringLiteral("You're not supposed to instantiate interfaces"));
     qmlRegisterSingletonType<DaemonDbusInterface>(uri, 1, 0, "DaemonDbusInterface", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return new DaemonDbusInterface;
     });
     qmlRegisterSingletonType<AbstractPointerLocker>("org.kde.kdeconnect", 1, 0, "PointerLocker", [](QQmlEngine *, QJSEngine *) -> QObject * {
         AbstractPointerLocker *ret;
-#if WITH_WAYLAND
+#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
         if (qGuiApp->platformName() == QLatin1String("wayland"))
             ret = new PointerLockerWayland;
         else
@@ -101,11 +101,7 @@ void KdeConnectDeclarativePlugin::registerTypes(const char *uri)
         return new OpenConfig;
     });
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
     qmlRegisterAnonymousType<QAbstractItemModel>(uri, 1);
-#else
-    qmlRegisterType<QAbstractItemModel>();
-#endif
 
     registerFactory<DeviceDbusInterface>(uri, "DeviceDbusInterfaceFactory");
     registerFactory<BatteryDbusInterface>(uri, "DeviceBatteryDbusInterfaceFactory");
@@ -113,13 +109,13 @@ void KdeConnectDeclarativePlugin::registerTypes(const char *uri)
     registerFactory<FindMyPhoneDeviceDbusInterface>(uri, "FindMyPhoneDbusInterfaceFactory");
     registerFactory<SftpDbusInterface>(uri, "SftpDbusInterfaceFactory");
     registerFactory<RemoteKeyboardDbusInterface>(uri, "RemoteKeyboardDbusInterfaceFactory");
+    registerFactory<ClipboardDbusInterface>(uri, "ClipboardDbusInterfaceFactory");
     registerFactory<MprisDbusInterface>(uri, "MprisDbusInterfaceFactory");
     registerFactory<RemoteControlDbusInterface>(uri, "RemoteControlDbusInterfaceFactory");
     registerFactory<LockDeviceDbusInterface>(uri, "LockDeviceDbusInterfaceFactory");
     registerFactory<SmsDbusInterface>(uri, "SmsDbusInterfaceFactory");
     registerFactory<RemoteCommandsDbusInterface>(uri, "RemoteCommandsDbusInterfaceFactory");
     registerFactory<ShareDbusInterface>(uri, "ShareDbusInterfaceFactory");
-    registerFactory<PhotoDbusInterface>(uri, "PhotoDbusInterfaceFactory");
     registerFactory<RemoteSystemVolumeDbusInterface>(uri, "RemoteSystemVolumeDbusInterfaceFactory");
     registerFactory<BigscreenDbusInterface>(uri, "BigscreenDbusInterfaceFactory");
     registerFactory<VirtualmonitorDbusInterface>(uri, "VirtualmonitorDbusInterfaceFactory");
@@ -133,3 +129,5 @@ void KdeConnectDeclarativePlugin::initializeEngine(QQmlEngine *engine, const cha
 
     engine->rootContext()->setContextProperty(QStringLiteral("DBusResponseWaiter"), DBusResponseWaiter::instance());
 }
+
+#include "moc_kdeconnectdeclarativeplugin.cpp"
